# perceptron_pypi
perceptron_pypi

# Reference -
[official python docs for pypi] (https://packaging.python.org/tutorials/packaging-projects/)

[github docs for github actions] (https://docs.github.com/en/actions/guides/building-and-testing-python#publishing-to-package-registries)